==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/IdentityProviderCredentials.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdentityProviderCredentialsClient;
import com.okta.sdk.resource.model.IdentityProviderCredentialsSigning;
import com.okta.sdk.resource.model.IdentityProviderCredentialsTrust;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentityProviderCredentials
 */
@JsonPropertyOrder({ IdentityProviderCredentials.JSON_PROPERTY_CLIENT,
        IdentityProviderCredentials.JSON_PROPERTY_SIGNING, IdentityProviderCredentials.JSON_PROPERTY_TRUST })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdentityProviderCredentials implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CLIENT = "client";
    private IdentityProviderCredentialsClient client;

    public static final String JSON_PROPERTY_SIGNING = "signing";
    private IdentityProviderCredentialsSigning signing;

    public static final String JSON_PROPERTY_TRUST = "trust";
    private IdentityProviderCredentialsTrust trust;

    public IdentityProviderCredentials() {
    }

    public IdentityProviderCredentials client(IdentityProviderCredentialsClient client) {

        this.client = client;
        return this;
    }

    /**
     * Get client
     *
     * @return client
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CLIENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderCredentialsClient getClient() {
        return client;
    }

    @JsonProperty(JSON_PROPERTY_CLIENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setClient(IdentityProviderCredentialsClient client) {
        this.client = client;
    }

    public IdentityProviderCredentials signing(IdentityProviderCredentialsSigning signing) {

        this.signing = signing;
        return this;
    }

    /**
     * Get signing
     *
     * @return signing
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SIGNING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderCredentialsSigning getSigning() {
        return signing;
    }

    @JsonProperty(JSON_PROPERTY_SIGNING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSigning(IdentityProviderCredentialsSigning signing) {
        this.signing = signing;
    }

    public IdentityProviderCredentials trust(IdentityProviderCredentialsTrust trust) {

        this.trust = trust;
        return this;
    }

    /**
     * Get trust
     *
     * @return trust
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TRUST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderCredentialsTrust getTrust() {
        return trust;
    }

    @JsonProperty(JSON_PROPERTY_TRUST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrust(IdentityProviderCredentialsTrust trust) {
        this.trust = trust;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentityProviderCredentials identityProviderCredentials = (IdentityProviderCredentials) o;
        return Objects.equals(this.client, identityProviderCredentials.client)
                && Objects.equals(this.signing, identityProviderCredentials.signing)
                && Objects.equals(this.trust, identityProviderCredentials.trust);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(client, signing, trust);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentityProviderCredentials {\n");
        sb.append("    client: ").append(toIndentedString(client)).append("\n");
        sb.append("    signing: ").append(toIndentedString(signing)).append("\n");
        sb.append("    trust: ").append(toIndentedString(trust)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/IdentityProviderCredentials.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdentityProviderCredentialsClient;
import com.okta.sdk.resource.model.IdentityProviderCredentialsSigning;
import com.okta.sdk.resource.model.IdentityProviderCredentialsTrust;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentityProviderCredentials
 */
@JsonPropertyOrder({ IdentityProviderCredentials.JSON_PROPERTY_CLIENT,
        IdentityProviderCredentials.JSON_PROPERTY_SIGNING, IdentityProviderCredentials.JSON_PROPERTY_TRUST })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdentityProviderCredentials implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CLIENT = "client";
    private IdentityProviderCredentialsClient client;

    public static final String JSON_PROPERTY_SIGNING = "signing";
    private IdentityProviderCredentialsSigning signing;

    public static final String JSON_PROPERTY_TRUST = "trust";
    private IdentityProviderCredentialsTrust trust;

    public IdentityProviderCredentials() {
    }

    public IdentityProviderCredentials client(IdentityProviderCredentialsClient client) {

        this.client = client;
        return this;
    }

    /**
     * Get client
     *
     * @return client
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CLIENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderCredentialsClient getClient() {
        return client;
    }

    @JsonProperty(JSON_PROPERTY_CLIENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setClient(IdentityProviderCredentialsClient client) {
        this.client = client;
    }

    public IdentityProviderCredentials signing(IdentityProviderCredentialsSigning signing) {

        this.signing = signing;
        return this;
    }

    /**
     * Get signing
     *
     * @return signing
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SIGNING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderCredentialsSigning getSigning() {
        return signing;
    }

    @JsonProperty(JSON_PROPERTY_SIGNING)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSigning(IdentityProviderCredentialsSigning signing) {
        this.signing = signing;
    }

    public IdentityProviderCredentials trust(IdentityProviderCredentialsTrust trust) {

        this.trust = trust;
        return this;
    }

    /**
     * Get trust
     *
     * @return trust
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TRUST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderCredentialsTrust getTrust() {
        return trust;
    }

    @JsonProperty(JSON_PROPERTY_TRUST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrust(IdentityProviderCredentialsTrust trust) {
        this.trust = trust;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentityProviderCredentials identityProviderCredentials = (IdentityProviderCredentials) o;
        return Objects.equals(this.client, identityProviderCredentials.client)
                && Objects.equals(this.signing, identityProviderCredentials.signing)
                && Objects.equals(this.trust, identityProviderCredentials.trust);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(client, signing, trust);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentityProviderCredentials {\n");
        sb.append("    client: ").append(toIndentedString(client)).append("\n");
        sb.append("    signing: ").append(toIndentedString(signing)).append("\n");
        sb.append("    trust: ").append(toIndentedString(trust)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
